'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _cspaceLayout = require('cspace-layout');

var _CancelButton = require('../navigation/CancelButton');

var _CancelButton2 = _interopRequireDefault(_CancelButton);

var _RunButton = require('../record/RunButton');

var _RunButton2 = _interopRequireDefault(_RunButton);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const propTypes = {
  isOpen: _propTypes2.default.bool,
  isRecordModified: _propTypes2.default.bool,
  invocationItem: _propTypes2.default.instanceOf(_immutable2.default.Map),
  messages: _propTypes2.default.objectOf(_propTypes2.default.object),
  runButtonClassName: _propTypes2.default.string,
  // type: PropTypes.oneOf(['report', 'batch']),
  onCancelButtonClick: _propTypes2.default.func,
  onCloseButtonClick: _propTypes2.default.func,
  onRunButtonClick: _propTypes2.default.func
};

class InvocationModal extends _react.Component {
  constructor() {
    super();

    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  renderButtonBar() {
    var _props = this.props;
    const messages = _props.messages,
          runButtonClassName = _props.runButtonClassName,
          onCancelButtonClick = _props.onCancelButtonClick,
          onRunButtonClick = _props.onRunButtonClick;


    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(_CancelButton2.default, {
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.cancel),
        onClick: onCancelButtonClick
      }),
      _react2.default.createElement(_RunButton2.default, {
        className: runButtonClassName,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.run),
        onClick: onRunButtonClick
      })
    );
  }

  render() {
    var _props2 = this.props;
    const isOpen = _props2.isOpen,
          isRecordModified = _props2.isRecordModified,
          invocationItem = _props2.invocationItem,
          messages = _props2.messages,
          onCloseButtonClick = _props2.onCloseButtonClick;


    if (!isOpen || !invocationItem) {
      return null;
    }

    let unsavedWarning;

    if (isRecordModified) {
      unsavedWarning = _react2.default.createElement(
        'p',
        null,
        _react2.default.createElement(_reactIntl.FormattedMessage, messages.unsaved)
      );
    }

    return _react2.default.createElement(
      _cspaceLayout.Modal,
      {
        isOpen: isOpen,
        title: _react2.default.createElement(
          'h1',
          null,
          invocationItem.get('name')
        ),
        closeButtonClassName: 'material-icons',
        closeButtonLabel: 'close',
        renderButtonBar: this.renderButtonBar,
        onCloseButtonClick: onCloseButtonClick
      },
      _react2.default.createElement(_reactIntl.FormattedMessage, messages.prompt),
      unsavedWarning
    );
  }
}

exports.default = InvocationModal;
InvocationModal.modalName = 'InvocationModal';
InvocationModal.propTypes = propTypes;